@@ -1,13 +1,15 @@
 import math
 
-def om_scale(list, minout, maxout, minin=0, maxin=0):
+def om_scale(om_self, minout, maxout, minin=0, maxin=0):
     "return a list of samples between min and max"
     if minin == 0 and maxin == 0:
         minin = min(list)
         maxin = max(list)
     new_scale = []
-    for i in list:
-        new_scale.append(minout + (((i - minin) * (maxout - minout)) / (maxin - minin )))
+    if type(om_self) != list:
+        om_self = [om_self]
+    for index in range(len(om_self)):
+        new_scale.append(minout + (((om_self[index] - minin) * (maxout - minout)) / (maxin - minin )))
     return new_scale
 
 
@@ -17,4 +19,12 @@ def f2mc(freq):
     else:
         ref_pitch = 440 
         diferenca_com_A4 =  6900 + (math.log(abs(freq / ref_pitch)) / math.log(2)) * 1200
-        return round(diferenca_com_A4, 2)
\ No newline at end of file
+        return round(diferenca_com_A4, 2)
+
+def mc2f(mc): 
+    if isinstance(mc, list):
+        return [mc2f(i) for i in mc]
+    if isinstance(mc, int) or isinstance(mc, float):
+        ref_pitch = 440 
+        return ref_pitch * (2 ** ((mc - 6900) / 1200))
+
